****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_setdatadrivenqueryperiod.sas  
*
* Created (mm/dd/yyyy): 06/16/2019
* Last modified: 
* Version: 1.0
*
*--------------------------------------------------------------------------------------------------
* PURPOSE:
*                                  
*   
*  Program inputs:                                                                                   
*                                     
*  Program outputs:                                                                                                                                       
*                                                                                                  
*  PARAMETERS:    
*            
*  Programming Notes:                                                                                
*                                                                           
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials      Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*
***************************************************************************************************;

%macro ms_setdatadrivenqueryperiod();	

	%put =====> MACRO CALLED: ms_setdatadrivenqueryperiod v1.0;

	**************************************************;
	* Monitoring file for Fixed Risk Window analysis *;
	**************************************************;

	%if %eval(&PERIODIDSTART.=1) %then %do;

		/****************/
		/* Type 2 and 3 */
		/****************/

		%if %eval(&type.=2)| %eval(&type.=3) %then %do;
			data &monitoringfile;
				set infolder.&monitoringfile.;
				format enddate dp_maxdate censordate date9.;
					
					*Add QA DP Max Date to file;
					dp_maxdate = &DP_MaxDate.;

					*determine date to use to determine last date of followup;
					if cdpend = 'Y' then do;
						if missing(fupenddate)=0 then do;
							censordate = min(dp_maxdate, fupenddate);
							call symputx("censor_dpend",1);
							call symputx("censor_qryend",1);
							call symputx("fupenddate", fupenddate);	
						end;
						else do;
							censordate = dp_maxdate;
							call symputx("censor_dpend",1);
							call symputx("fupenddate", dp_maxdate);	
						end;
					end;
					else if cdpend = 'N' then do;
						censordate = fupenddate;
						call symputx("censor_qryend",1);
						call symputx("fupenddate", fupenddate);	
					end;

					*Add enddate to monitoring file;
					%if %eval(&type.=2) %then %do;
						enddate = INTNX('Month', censordate-max(&ITTDAYS.,&MAXEPISDUR.,0, &enrdaysaftInd.),0, 'begin')-1;
					%end;
					%if %eval(&type.=3) %then %do;
						enddate = INTNX('Month', censordate-max(&T3RiskTo.,&T3CtrlTo.,0, &enrdaysaftInd.),0, 'begin')-1;
					%end;
			run;		

		%end;

		/*****************************************************************************************/
		/* Type 4 - will extract maximum end date for group, then restrict in ms_createmicohorts */
		/*****************************************************************************************/
		%if %eval(&type.=4) %then %do;
			data &monitoringfile;
				set infolder.&monitoringfile.;
				format enddate dp_maxdate censordate date9.;
					
					*Add QA DP Max Date to file;
					dp_maxdate = &DP_MaxDate.;

					*determine date to use to determine last date of followup;
					if cdpend = 'Y' then do;
						if missing(fupenddate)=0 then censordate = min(dp_maxdate, fupenddate);
						else censordate = dp_maxdate;
					end;
					else if cdpend = 'N' then do;
						censordate = fupenddate;
					end;

					*Add enddate to monitoring file;
					enddate = censordate;
			run;		
		%end;

	%end;

	/************/
	/* Looks 2+ */
	/************/
	%if %eval(&PERIODIDSTART.>1) %then %do;

		/****************/
		/* Type 2 and 3 */
		/****************/

		%if %eval(&type.=2)|%eval(&type.=3) %then %do;

			*Create monitoringfile to mimic looks;
			proc sql noprint;
				create table &monitoringfile. as 
				select x.*,
					   y.expperiodenddt,
					   y.startdate as survstartdate
				from infolder.&monitoringfile. as x left join 
					 infolder.&metadatafile. as y
				on lowcase(group) = lowcase("&itgroup.") and 
					y.timeperiod = x.periodid and 
					lowcase(y.runid) = lowcase("&runid.")
				order by periodid;
			quit;

			*Determine censor date for current look;
			data &monitoringfile.;
				set &monitoringfile.;
				format startdate enddate dp_maxdate censordate date9.;
				by periodid;

					lagstart = lag(survstartdate);
					if startdate = .M then do;
						startdate = lagstart;
					end;

					if periodid = "&periodidstart" then do;

						*Add QA DP Max Date to file;
						dp_maxdate = &DP_MaxDate.;

						*determine date to use to determine last date of followup;
						if cdpend = 'Y' then do;
							if missing(fupenddate)=0 then do;
								censordate = min(dp_maxdate, fupenddate);
								call symputx("censor_dpend",1);
								call symputx("censor_qryend",1);
								call symputx("fupenddate", fupenddate);	
							end;
							else do;
								censordate = dp_maxdate;
								call symputx("censor_dpend",1);
								call symputx("fupenddate", dp_maxdate);	
							end;
						end;
						else if cdpend = 'N' then do;
							censordate = fupenddate;
							call symputx("censor_qryend",1);
							call symputx("fupenddate", fupenddate);	
						end;

						*Add enddate to monitoring file;
						%if %eval(&type.=2) %then %do;
							enddate = INTNX('Month', censordate-max(&ITTDAYS.,&MAXEPISDUR.,0, &enrdaysaftInd.),0, 'begin')-1;
						%end;
						%if %eval(&type.=3) %then %do;
							enddate = INTNX('Month', censordate-max(&T3RiskTo.,&T3CtrlTo.,0, &enrdaysaftInd.),0, 'begin')-1;
						%end;
					end;
					else do;
						enddate = expperiodenddt;
					end;

					drop lagstart;
			run;

		%end;

		/**********/
		/* Type 4 */
		/**********/

		%if %eval(&type.=4) %then %do;
			%put ERROR: This functionality is not currently available.;
			%abort;
		%end;

	%end;

	*Set Query period macro variables:
		*startdate = start of surveillance period
		*enddate = end of surveillance period (index date)
		*ExpPeriodStartDt = Look start date;
		*ExpPeriodEndDt = look end date;

	*Take min startdate and max enddate;
	proc means data=&Monitoringfile. nway noprint;
		var startdate enddate censordate;
	    output out=monitoringfile_agg min(startdate)=startdate
	                                   	    max(enddate)=enddate
											max(censordate)=censordate;
	run; 

	data _null_;
	   set monitoringfile_agg;    
	   call symputx("startdate",startdate);
	   call symputx("enddate",enddate);    
	   call symputx("censordate",censordate);    
	run;
	%put &startdate. &enddate. &censordate;

	* Create Non Overlapping Looks dates;
	proc sort data=&Monitoringfile. out=looks;
		by PERIODID;
	run;

	data looks;
		set looks;
	    format lenddate LookStart LookEnd date9.;
	    LookStart=startdate;
	    LookEnd=enddate;
	    if periodid>1 then LookStart=lenddate+1;
	    lenddate=enddate;
	    retain lenddate;
	    rename PeriodId = Look;
	    keep PeriodId LookStart LookEnd;
	run; 

	data _null_;
		set looks;    
	   	if look = &periodidstart. then do;
	   		call symputx("ExpPeriodStartDt",lookstart);
			call symputx("ExpPeriodEndDt",lookend); 
		end; 
	run;
	%put &ExpPeriodStartDt. &ExpPeriodEndDt.;

	*Counter for output files;
	data _null_;
		call symputx("MinExpPeriodStartDt", min(&MinExpPeriodStartDt., &ExpPeriodStartDt.));
		call symputx("MaxExpPeriodEndDt",max(&MaxExpPeriodEndDt., &ExpPeriodEndDt.));
	run;

	*Assign calendar based global macro vars;
	%ms_assigncalmacrovars(date1=&ExpPeriodStartDt., date2=&ExpPeriodEndDt.);

	*Save metadata file for types 2 and 3;
	%if %eval(&type.=2) | %eval(&type.=3) %then %do;
		data _metadata;
			retain reqid runid group timeperiod startdate expperiodstartdt expperiodenddt survenddate;
			merge &monitoringfile.(keep=startdate censordate periodid rename=censordate =survenddate rename=periodid=timeperiod where=(timeperiod=&periodidstart.))
				looks(keep=look lookstart lookend where=(timeperiod=&periodidstart.) 
					rename=look=timeperiod rename=lookstart=expperiodstartdt rename=lookend = expperiodenddt);
			by timeperiod;

			format reqid $40. runid $3. group $40. startdate expperiodstartdt expperiodenddt survenddate date9.;
			length reqid $40 runid $3 group $40;

			reqid = "&reqid.";
			runid = "&runid.";
			group = "&itgroup.";
		run;

		*First Look;
		%if %eval(&PERIODIDSTART.=1) %then %do;
			%if %eval(&group.=1) %then %do;
				data msoc.&runid._metadata_for_time_period_&PERIODIDSTART.;
					set _metadata;
				run;
			%end;
			%else %do;
				proc append base=msoc.&runid._metadata_for_time_period_&PERIODIDSTART.
					data=_metadata force;
				run;
			%end;
		%end;
		/*Subsequent looks*/
		%if %eval(&PERIODIDSTART.>1) %then %do;
			%if %eval(&group.=1) %then %do;
				data msoc.&runid._metadata_for_time_period_&PERIODIDSTART.;
					set infolder.&metadatafile.
						_metadata;
				run;
			%end;
			%else %do;
				proc append base=msoc.&runid._metadata_for_time_period_&PERIODIDSTART.
					data=_metadata force;
				run;
			%end;
		%end;

	%end;

	%put NOTE: ******** END OF MACRO: ms_setdatadrivenqueryperiod v1.0 ********;

%mend ms_setdatadrivenqueryperiod;
