****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_t1t2_initializemacrovariables.sas  
*
* Created (mm/dd/yyyy): 12/27/2017
* Last modified: 06/30/2019
* Version: 1.4
*
*--------------------------------------------------------------------------------------------------
* PURPOSE: The macro initializes global macro variables
*
*  Program inputs:                                                                                   
* 
*  Program outputs:                                                                                                                                       
*
*  PARAMETERS:                                                                       
*            
*  Programming Notes:                                                                                
*                                                                           
*
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials      Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*	 1.1	  04/16/18	  AP		Replaced Dispensings with AdjustedCodeCount/RawCodeCount
*
*	 1.2	  07/16/18	  AP		Added covariate stratification
*
*	 1.3	  12/16/18	  AP		Changed font from calibri to arial
*									Changed macro name from ms_initializemacrovariables to ms_t1t2_initializemacrovariables
*
*	 1.4	  06/30/19	  AP		Updated monitoring file for QRP 8.0.0
*
***************************************************************************************************;

%macro ms_t1t2_initializemacrovariables();

	%put =====> MACRO CALLED: ms_t1t2_initializemacrovariables v1.4;

	/*variables related to groups, runs and dplist*/
	%global T1runids;
	%let T1runids =;
	%global NUM_T1runids;
	%let NUM_T1runids = .;
	%global T1GroupList;
	%let T1GroupList =;
	%global NUM_T1Groups;
	%let NUM_T1Groups = .;
	%global T1GroupList_;

	/*combined groups*/
	%global NUM_Crunids;
	%let NUM_Crunids=.;
	%global combinerun1;
	%let combinerun1 = ;
	%global combinerun2;
	%let combinerun2=;
	%global combinegroup1;
	%let combinegroup1=;
	%global combinegroup2;
	%let combinegroup2=;

	/*All runs*/
	%global allgroups;
	%let allgroups=;
	%global Num_allgroups;
	%let Num_allgroups=.;
	%global numrunids;
	%let numrunids=.;
	%global runids;
	%let runids=;
	/*header*/
	%global header;
	%let header=;

	/*columns to remove from the table*/
	%global rmvarlist;
	%let rmvarlist=;

	/*Dps*/
	%global num_dp;
	%let num_dp=1;
	%global random_dpid_list;
	%let random_dpid_list=&dpidlist.;

	/*table counts and letter*/
	%global tablecount;
	%global tableletter;
	%let tablecount = 1;
	%let tableletter = a;

	/*Default list of variables to be included*/
	%global contvars origvars allvars classvars classlist defaultlist type1exclude;
	%let contvars = Npts Episodes AdjustedCodeCount RawCodeCount DaySupp AmtSupp Eps_wEvents All_Events tte ttediv36525 DenNumPts DenNumMemDays DenNumMemDaysdiv36525;
	%let origvars = Npts Episodes AdjustedCodeCount RawCodeCount DaySupp AmtSupp Eps_wEvents All_Events tte DenNumPts DenNumMemDays;
	%let classvars = combinegrouplabel level sex year Agegroup Agegroupnum month zip3 state hhs_reg cb_reg race hispanic zip_uncertain;
	%let allvars = npts dennumpts nptsdivdennumpts episodes tte ttediv36525 adjustedcodecount rawcodecount adjustedcodecountdivnpts rawcodecountdivnpts daysupp daysuppdivnpts 
		daysuppdivepisodes daysuppdivadjustedcodecount daysuppdivrawcodecount amtsupp amtsuppdivepisodes amtsuppdivadjustedcodecount amtsuppdivrawcodecount all_events eps_wevents eps_weventsdivnpts 
		eps_weventsdivepisodes eps_weventsdivttediv36525 eps_weventsdivdennumpts dennummemdays dennummemdaysdiv36525;
	%let type1exclude = Eps_wEvents All_Events tte ttediv36525 eps_weventsdivnpts eps_weventsdivepisodes eps_weventsdivttediv36525 eps_weventsdivdennumpts;
	%let classlist=;
	%let defaultlist=;

	/*custom variables*/
	%global customvars newcustomvars numcustomvars;
	%let customvars=;
	%let newcustomvars=;
	%let numcustomvars=.;

	/*custom title*/
	%global labeltitle;
	%let labeltitle=;
	%global strat;
	%let strat=;

	/*continous variables in agg data*/
	%global varlistagg varlistagg_nodenom varlistdp varlistdp_nodenom ;
	%let varlistagg=;
	%let varlistdp=;
	%let varlistagg_nodenom=;
	%let varlistdp_nodenom=;

	*Covariates;
	%global covarlist;
	%let covarlist = ;

	/*race, hispanic, state, zip3*/
	%global zip3level statelevel hhslevel cblevel racelevel hispaniclevel zip_uncertain;
	%let zip3level=;
	%let statelevel=;
	%let hhslevel = ;
	%let cblevel = ;
	%let racelevel =;
	%let hispaniclevel=;
	%let zip_uncertain=;

	/*race and hispanic*/
	%global race_where;
	%let race_where =.;
	%global hispanic_where;
	%let hispanic_where = .;
	%global demographic_footnote;
	%let demographic_footnote =;
	%global demographic_modifier;
	%let demographic_modifier=;
	%global race_out;
	%let race_out=;
	%global hispanic_out;
	%let hispanic_out=;

	%global ALLGROUPLABEL allbaselinelabel;

	/*CDF*/
	/*Censoring criteria to display*/
	%global all_censor_criteria;
	%if "&type" = "1" %then %do;
	%let all_censor_criteria = cens_elig cens_dth cens_dpend cens_qryend; 
	%end;
	%if "&type" = "2" %then %do;
	%let all_censor_criteria = cens_elig cens_dth cens_dpend cens_qryend cens_episend cens_spec cens_event; 
	%end;
	%if %isBlank(&censoring_display) > 0 %then %let censoring_display = &all_censor_criteria.;


	/*Logo*/
	%global report_header;
	%let report_header = title1 j=L font=arial h=12pt "Confidential ^n Do Not Distribute" ;	
	%if %isBlank(&logo) = 0 %then %let report_header = title j=R '^S={preimage="&infolder./&logo."}' j=L font=arial h=11pt "^S={vjust=m}Confidential ^n Do Not Distribute" ;

	*baseline table;
	%global FinalRecordedHistory;
	%global FinalHistoryofUse;
	%global FinalUtilization;

	/*Montoring file*/
	%global startdate enddate enddate2 enddate3;
	%isdata(dataset=infolder.&Monitoringfile.);
	%if %eval(&nobs.>0) %then %do;

		data &monitoringfile.;
			set infolder.&monitoringfile.;
				
				*Add QA DP Max Date to file;
				dp_maxdate = &DP_MaxDate.;

				/*Assign index assessment period end date*/
				if missing(indenddate) = 0 then do;
					enddate = indenddate;
				end;
				else do;
					if upcase(indendoptions) = 'FUPDRIVEN' then do;
						*FUPDRIVEN - query period ends at the earliest of FUPENDATE/CDPEND;
					 	if cdpend = 'N' then do;		
							enddate = fupenddate;
						end;
						else if cdpend = 'Y' then do;

							*check to see if dp_maxdate is prior to startdate;
							if dp_maxdate < startdate then do;
								fupenddate = startdate; /*recode FUPENDDATE to beginning of query period*/
							end;

							if missing(fupenddate) = 1 then enddate = dp_maxdate;
							else enddate = min(fupenddate, dp_maxdate);
						end;
					end;
				end;

				*Assign censordate;
				if cdpend = 'N' and missing(fupenddate) then do;
					censordate = .; /*no censor date*/
				end;
				else if cdpend = 'N' then do;
					censordate = fupenddate;
					call symputx("censor_qryend",1);
					call symputx("fupenddate", fupenddate);	
				end;
				else if cdpend = 'Y' and missing(fupenddate) then do;
					censordate = dp_maxdate;
				 	call symputx("censor_dpend",1);
					call symputx("fupenddate", dp_maxdate);	
				end;
				else if cdpend = 'Y' and not missing(fupenddate) then do;
					censordate = min(dp_maxdate, fupenddate);
				 	call symputx("censor_dpend",1);
					call symputx("censor_qryend",1);
					call symputx("fupenddate", fupenddate);	
				end;

				format enddate dp_maxdate censordate date9.;
		run;

		proc means data=&Monitoringfile. nway noprint;
		 	var startdate enddate ;
		 	output out= Monitoringfile min(startdate)=startdate
		                                    max(enddate)=enddate;
		run;
		   
		data monitoringfile;
			set Monitoringfile;
			call symputx("startdate",put(startdate, worddate.));
		    call symputx("enddate",put(enddate, worddate.)); 
			call symputx("enddate2", put(enddate, mmddyy10.));
			call symputx("enddate3", put(enddate, date9.));
		run;
	%end;
	%else %do;
		%put WARNING: infolder.&Monitoringfile. does not exist. Please confirm file is correctly named. Program will abort;
		%abort; 
	%end;

	%put =====> MACRO ENDED: ms_t1t2_initializemacrovariables v1.4;

%mend ms_t1t2_initializemacrovariables;
