****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: runreport.sas  
*
* Created (mm/dd/yyyy): 12/26/2017
* Last modified: 03/1/2019
* Version: 2.3
*
*--------------------------------------------------------------------------------------------------
* PURPOSE:
*   Macro to create reports                                        
*   
*  Program inputs:                                                                                   
*                                     
*  Program outputs:                                                                                                                                       
*                                                                                                  
*  PARAMETERS:    
*		All the parameters are set by the run_programs program. 
*            
*  Programming Notes:                                                                                
*
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials      Comment (reference external documentation when available)
*   -------   --------   --------   ----------------------------------------------------------------
*   1.1	  	  03/28/18	 AP			Changed name of log, fixed baseline without covar bug (QRP-526)
*
*   1.2	  	  06/15/18	 AP			Added USERSTRATA and COVARIATECODES parameter
*
*   2.0	  	  12/18/18	 AP			Added Type 5 report
*
*   2.1	  	  02/27/18	 AP			Applied format to Enddate parameter
*
*   2.2	  	  02/28/19	 AP			Changed DPID/SITEID to DP
*
*   2.3	  	  03/01/19	 AP			Added new Type 5 parameters
*
****************************************************************************************************;

%macro runreport ;

%if "&CREATEREPORT_TYPE" ne %str("") | %length(&CREATEREPORT_TYPE) > 0 %then %do;

	%if "&CREATEREPORT_TYPE" = "1" | "&CREATEREPORT_TYPE" = "2" %then %do;
		data _null_;
			set infolder.&CREATEREPORT_T1T2_FILE.;
			/*requestID (specified by the analyst - for file naming*/
			call symputx("requestID", requestID);
		run;
	%end;
	%if "&CREATEREPORT_TYPE" = "5" %then %do;
	data _null_;
			set infolder.&CREATEREPORT_T5_FILE.;
			/*requestID (specified by the analyst - for file naming*/
			call symputx("requestID", requestID);
		run;
	%end;

  	proc printto log="&MSOC.report_&requestID..log" new;
  	run;

  	%put =====> MACRO CALLED: runREPORT v2.3;

  	*Clean work library;
  	proc datasets lib=work nolist kill; quit; run;

	%if "&CREATEREPORT_TYPE" = "1" | "&CREATEREPORT_TYPE" = "2" %then %do;

	  	*Assign parameters;
		data _null_;
			set infolder.&CREATEREPORT_T1T2_FILE.;
			/* Specify the name of the SAS file to define groups (Required)*/
			call symputx("groupfile", groups_table);
			/* Specify the name of the SAS input file for customized columns (Optional)*/
			/* If left blank, default columns and labels will be displayed*/
			call symputx("columns_table", columns_table);
			/* Type: Enter 1 for type1 and 2 for type2*/
			call symputx("type", type);
			/* Name of type files separated by a space
			  if groups are in different type file, specify each of them */
			call symputx("alltypefiles", alltypefiles);
			/* Enter the name of the monitoring file for Query start and end dates*/
			call symputx("monitoringfile", monitoringfile);
			/* Name of cohort files separated by a space
			  if groups are in different cohort file, specify each of them */
			call symputx("cohortfile", cohortfile);
			/* Enter the name of the USERSTRATA file for the run*/
			call symputx("userstrata", userstrata);
			/* Enter the name of the COVARIATECODES file for the run*/
			call symputx("covariatecodes", covariatecodes);
			/* The title below goes in the blank section of the automated title*/
			call symputx("customtitle", customtitle);
			/*variables to be removed from report (Optional)*/
			/*0= no exclusion; 1= Npts; 2= Episodes; 3= Dispensings; 4= DaySupp; 5= AmtSupp; 
			  6= Eps_wEvents; 7= All_Events; 8= TTE; 9= TTE/365.25; 10= DenNumPts;
			  11= DenNumMemDays; 12=DenNumMemDays/365.25*/
			call symputx("exclude", exclude);
			/* Enter stratification level separated by space */
			call symputx("stratify_by_level", stratify_by_level);
			/*To add in State for ZIP3 level stratification, enter the name of the zip lookup file*/
			call symputx("zipfile", zipfile);
			/*Specify how agegroup should be displayed */
			call symputx("agegroupfmt", agegroupfmt);
			/*Specify file name (including extension) for logo to display in report. Logo should be in JPG.
			 Optional, leave blank if no logo */
			call symputx("logo", logo);
			/*Enter Y or N if you want to run Baseline Table 1*/
			call symputx("Output_baselinetable", upcase(output_baselinetable));
			/* Look #s */
			call symputx("look_start", look_start);
			call symputx("look_end", look_end);

			/*Output CDF plot (Reason for Censor) and KM plot (time to event): Specify Y or N*/
			call symputx("Output_CDF_KM", Output_CDF_KM);

			/*Titles: Option to specify 2 titles (i.e. Title1) */
			call symputx("cdf_title1", cdf_title1);
			call symputx("km_title1", km_title1);
			call symputx("km_title2", km_title2);

			/*Footnotes: Option to specify 2 footnotes (i.e. Footnote1 Footnote2).*/
			call symputx("cdf_footnote1", cdf_footnote1);
			call symputx("km_footnote1", km_footnote1);
			call symputx("cdf_footnote2", cdf_footnote2);
			call symputx("km_footnote2", km_footnote2);


			/*X and Y axis scaling. For both the CDF and KM curve, user has the option to be specify Min, Max, and Tick values. 
			  Default x axis is 0 to max of data. Default y axis is 0-1.
			  Specify as: 
					%let cdf_xmin = 0;
					%let cdf_xmax = 200;
					%let cdf_xtick = 50; This creates xaxis values of (0 50 100 150 200)
			  NOTE: For each axis, each parameter (min, max, tick) must either be specified or left blank  */

			if missing(cdf_xmin)=1 then call symputx("cdf_xmin",'');
			else call symputx("cdf_xmin", cdf_xmin);
			if missing(cdf_xmax)=1 then call symputx("cdf_xmax",'');
			else call symputx("cdf_xmax", cdf_xmax);
			if missing(cdf_xtick)=1 then call symputx("cdf_xtick",'');
			else call symputx("cdf_xtick", cdf_xtick);
			if missing(km_xmin)=1 then call symputx("km_xmin",'');
			else call symputx("km_xmin", km_xmin);
			if missing(km_xmax)=1 then call symputx("km_xmax",'');
			else call symputx("km_xmax", km_xmax);
			if missing(km_xtick)=1 then call symputx("km_xtick",'');
			else call symputx("km_xtick", km_xtick);

			if missing(cdf_ymin)=1 then call symputx("cdf_ymin",'');
			else call symputx("cdf_ymin", cdf_ymin);
			if missing(cdf_ymax)=1 then call symputx("cdf_ymax",'');
			else call symputx("cdf_ymax", cdf_ymax);
			if missing(cdf_ytick)=1 then call symputx("cdf_ytick",'');
			else call symputx("cdf_ytick", cdf_ytick);
			if missing(km_ymin)=1 then call symputx("km_ymin",'');
			else call symputx("km_ymin", km_ymin);
			if missing(km_ymax)=1 then call symputx("km_ymax",'');
			else call symputx("km_ymax", km_ymax);
			if missing(km_ytick)=1 then call symputx("km_ytick",'');
			else call symputx("km_ytick", km_ytick);

			/*For total episodes KM Curve*/
			if missing(km_ep_xmin)=1 then call symputx("km_ep_xmin",'');
			else call symputx("km_ep_xmin", km_ep_xmin);
			if missing(km_ep_xmax)=1 then call symputx("km_ep_xmax",'');
			else call symputx("km_ep_xmax", km_ep_xmax);
			if missing(km_ep_xtick)=1 then call symputx("km_ep_xtick",'');
			else call symputx("km_ep_xtick", km_ep_xtick);
			if missing(km_ep_ymin)=1 then call symputx("km_ep_ymin",'');
			else call symputx("km_ep_ymin", km_ep_ymin);
			if missing(km_ep_ymax)=1 then call symputx("km_ep_ymax",'');
			else call symputx("km_ep_ymax", km_ep_ymax);
			if missing(km_ep_ytick)=1 then call symputx("km_ep_ytick",'');
			else call symputx("km_ep_ytick", km_ep_ytick);

			/*Specify censoring criteria. By default, all censoring criteria is displayed.*/
			call symputx("censoring_display", censoring_display);

			/*Specify label for each censoring criteria. Only need to fill out for variables chosen to display*/
			call symputx("cens_elig", cens_elig);
			call symputx("cens_dth", cens_dth);
			call symputx("cens_dpend", cens_dpend);
			call symputx("cens_qryend", cens_qryend);
			call symputx("cens_episend", cens_episend);
			call symputx("cens_spec", cens_spec);
			call symputx("cens_event", cens_event);

			/*Specify if 'N' should be displayed within graphs (Y/N)*/
			call symputx("displayn", displayn);
			/* Line spacing. Default = 1.75. Modify to lengthen or tighten table to prevent orphan lines */
			call symputx("line_spacing", line_spacing);

		run;

		*additional default parameters;
		%let dpidlist = &dp.;
		%let Stratify_by_DP = N;

	  	%ms_t1t2_createreport();

 	%end;

	%if "&CREATEREPORT_TYPE" = "5" %then %do;

	  	*Assign parameters;
		data _null_;
			set infolder.&CREATEREPORT_T5_FILE.;
			/* Name of type5files separate by a space
			  if groups are in different type file, specify each of them */
			call symputx("type5file", type5file);
			/* Specify the name of the SAS file to define groups (Required)*/
			call symputx("groupfile", groupfile);
			/* Specify the name of the SAS input file to define tables/figures (Required) */
			call symputx("tablefile", tablefile);
			/* Specify the name of the SAS input file to define levelIDs (Required) */
			call symputx("levellookup", levellookup);
			/* Enter the name of the USERSTRATA file for the run */
			call symputx("userstrata", userstrata);
			/* Enter Y or N if you want to run Baseline Table 1 */
			call symputx("output_baselinetable", upcase(output_baselinetable));
			/* User defined stratification categories for dispensing days supplied */
			call symputx("dispdayssupstrat", dispdayssupstrat);
			/* User defined stratification categories for total episode duration */
			call symputx("totepisdurstrat", totepisdurstrat);
			/* User defined stratification categories for first episode duration */
			call symputx("episdurstrat", episdurstrat);
			/* Request end date */
			call symputx("enddate", put(enddate, mmddyy10.));
			/* Look #s */
			call symputx("look_start", look_start);
			call symputx("look_end", look_end);

			*Figures;

			/*X and Y axis scaling. For both the Figures 4 and 5, user has the option to be specify Min, Max, and Tick values. 
			 Default x axis is 0 to max of data. Default y axis is 0-1.
			 Specify as: 
					%let km_f4_xmin = 0;
					%let km_f4_xmax = 200;
					%let km_f4_xtick = 50; This creates xaxis values of (0 50 100 150 200)
			NOTE: For each axis, each parameter (min, max, tick) must either be specified or left blank  */

			if missing(km_f4_xmin)=1 then call symputx("km_f4_xmin",'');
			else call symputx("km_f4_xmin", km_f4_xmin);
			if missing(km_f4_xmax)=1 then call symputx("km_f4_xmax",'');
			else call symputx("km_f4_xmax", km_f4_xmax);
			if missing(km_f4_xtick)=1 then call symputx("km_f4_xtick",'');
			else call symputx("km_f4_xtick", km_f4_xtick);

			if missing(km_f4_ymin)=1 then call symputx("km_f4_ymin", 0);
			else call symputx("km_f4_ymin", km_f4_ymin);
			if missing(km_f4_ymax)=1 then call symputx("km_f4_ymax", 1);
			else call symputx("km_f4_ymax", km_f4_ymax);
			if missing(km_f4_ytick)=1 then call symputx("km_f4_ytick", .2);
			else call symputx("km_f4_ytick", km_f4_ytick);

			if missing(km_f5_xmin)=1 then call symputx("km_f5_xmin",'');
			else call symputx("km_f5_xmin", km_f5_xmin);
			if missing(km_f5_xmax)=1 then call symputx("km_f5_xmax",'');
			else call symputx("km_f5_xmax", km_f5_xmax);
			if missing(km_f5_xtick)=1 then call symputx("km_f5_xtick",'');
			else call symputx("km_f5_xtick", km_f5_xtick);

			if missing(km_f5_ymin)=1 then call symputx("km_f5_ymin", 0);
			else call symputx("km_f5_ymin", km_f5_ymin);
			if missing(km_f5_ymax)=1 then call symputx("km_f5_ymax", 1);
			else call symputx("km_f5_ymax", km_f5_ymax);
			if missing(km_f5_ytick)=1 then call symputx("km_f5_ytick", .2);
			else call symputx("km_f5_ytick", km_f5_ytick);

			call symputx("censoring_display_f5", lowcase(censoring_display_f5));
			call symputx("censoring_label_f5", lowcase(censoring_label_f5));

			/*Specify file name (including extension) for logo to display in report. Logo should be in JPG.
			 Optional, leave blank if no logo */
			call symputx("logo", logo);
			/* Line spacing. Default = 1.75. Modify to lengthen or tighten table to prevent orphan lines */
			call symputx("line_spacing", line_spacing);
		run;

		*additional default parameters;
		%let dpidlist = &dpid;
		%let dp_stratification = N;

	  	%ms_t5_createreport();

 	%end;

  	%put NOTE: ******** END OF MACRO: runREPORT v2.3 ********;

  	proc printto;
  	run;

%end;

%mend runreport ;

%runreport ;
