****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: runqrp.sas  
*
* Created (mm/dd/yyyy): 01/26/2016
* Last modified: 
* Version: 8.0.2
*
*--------------------------------------------------------------------------------------------------
* PURPOSE:
*   Macro to run QRP analytic code                                    
*   
*  Program inputs:                                                                                   
*                                     
*  Program outputs:                                                                                                                                       
*                                                                                                  
*  PARAMETERS:    
*       All the parameters are set by the run_programs program. 
*            
*  Programming Notes:                                                                                
*
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials      Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*             mm/dd/yy
*
***************************************************************************************************;
/* Macro to run CIDA and Analytic Code if necessary */

%macro runqrp ;

  %LET RUNID=%LOWCASE(&RUNID.);

  proc printto log="&MSOC.&RUNID._cida.log" new;
  run;

  %put =====> MACRO CALLED: runqrp v8.0.2;

  %let QRPVer=8.0.2;  
  
  *Enter version for any custom code written on top of QRP;
  %let CustomCodeVer = ;

  /*option required to ensure successful multiple runs of CIDA*/
  options nosyntaxcheck;

  *Clean work library;
  proc datasets lib=work nolist kill; quit; run;

  *Clean dplocal library of temporary datasets;
  proc datasets lib=dplocal nolist nowarn;
    delete _: death: drug: med: mil: enr: elix: pre: lab:;
  quit;

  /**********/
  /** CIDA **/
  /**********/
  %ms_cidanum(RUNID=&RUNID.,
              PROJID=&PROJID.,  
              WPTYPE=&WPTYPE.,
              WPID=&WPID.,
              DPID=&DPID.,
              VERID=&VERID.,
              PERIODIDSTART=&PERIODIDSTART.,
              PERIODIDEND=&PERIODIDEND.,
              ANALYSIS=&ANALYSIS.,
              MONITORINGFILE=&MONITORINGFILE.,
              USERSTRATA=&USERSTRATA.,
              COMBOFILE=&COMBOFILE.,
              COHORTFILE=&COHORTFILE.,
              COHORTCODES=&COHORTCODES.,
              INCLUSIONCODES=&INCLUSIONCODES.,
              STOCKPILINGFILE=&STOCKPILINGFILE.,
              RUN_ENVELOPE=&RUN_ENVELOPE.,
              FREEZEDATA=&FREEZEDATA.,
              ZIPFILE=&ZIPFILE.,
              LABSCODEMAP=&LABSCODEMAP.,
              DISTINDEX=&DISTINDEX.,
              TYPE1FILE=&TYPE1FILE.,
              TYPE2FILE=&TYPE2FILE.,
              TYPE3FILE=&TYPE3FILE.,
              TYPE4FILE=&TYPE4FILE.,
              PREGDUR=&PREGDUR.,    
              TYPE5FILE=&TYPE5FILE.,
              TYPE6FILE=&TYPE6FILE.,
              METADATAFILE=&METADATAFILE.,
              SURVEILLANCEMODE=&SURVEILLANCEMODE.,
              COVARIATECODES=&COVARIATECODES.,
              UTILFILE=&UTILFILE.,
              COMORBFILE=&COMORBFILE.,
              DRUGCLASSFILE=&DRUGCLASSFILE.,
              PROFILE=&PROFILE.,
              MFUFILE=&MFUFILE.,
              MULTEVENTFILE=&MULTEVENTFILE.,
              MULTEVENTFILE_ADHERE=&MULTEVENTFILE_ADHERE.,
              CONCFILE=&CONCFILE.,
              OVERLAPFILE=&OVERLAPFILE.,
              OVERLAPFILE_ADHERE=&OVERLAPFILE_ADHERE.,
              ITSFILE=&ITSFILE.,
              TREATMENTPATHWAYS=&TREATMENTPATHWAYS.,
              MICOHORTFILE=&MICOHORTFILE.,
              TREEFILE=&TREEFILE.,
              TREELOOKUP=&TREELOOKUP.,
              ICD10ICD9MAP=&ICD10ICD9MAP.,
              COVARIATES_CONSIDERED=&COVARIATES_CONSIDERED.,
              COVARIATES_SELECTED=&COVARIATES_SELECTED.,
              RANKING=&RANKING.,
              ZERO_CELL_CORR=&ZERO_CELL_CORR.,
              HDVARSEL_INPUT=&RUNID._claims_ICDDX09 &RUNID._claims_ICDDX10 &RUNID._claims_DRUGCLASS &RUNID._claims_CPT &RUNID._claims_ICDPX09 &RUNID._claims_ICDPX10 &RUNID._claims_HCPCS,                          
              COMPARISON=&COMPARISON.,
              ANALYTICSUBGROUPS=&ANALYTICSUBGROUPS.,
              INDLEVEL=&INDLEVEL.,
              PERCENTILES=&PERCENTILES.,
              UNCONDITIONAL=&UNCONDITIONAL.,
              DIAGNOSTICS=&DIAGNOSTICS.
              );  

  %put NOTE: ******** END OF MACRO: runqrp v8.0.2 ********;

  *Clear work;
  proc datasets nowarn noprint lib=work kill;
  quit;

  proc printto;
  run;

%mend runqrp ;

%runqrp ;
